package com.dahe.gldriver.ui.account.authperson

import android.os.Bundle
import android.view.View
import androidx.core.widget.ContentLoadingProgressBar
import com.dahe.gldriver.R
import com.dahe.gldriver.bean.OcrPersonBean
import com.dahe.gldriver.bean.UpDriverInfoBean
import com.dahe.gldriver.bean.UpPersonInfoBean
import com.dahe.gldriver.callback.OnOcrPicResultListener
import com.dahe.gldriver.databinding.ActivityAuthDriverBinding
import com.dahe.gldriver.net.BaseObserver
import com.dahe.gldriver.net.DataManager
import com.dahe.gldriver.net.RxHttpCallBack
import com.dahe.gldriver.oss.OssServiceUtil
import com.dahe.gldriver.utils.OcrUtils
import com.dahe.mylibrary.utils.PickerUtils
import com.dahe.mylibrary.base.BaseActivity
import com.dahe.mylibrary.net.CommonResponseBean
import com.dahe.mylibrary.utils.ActivityUtils
import com.dahe.mylibrary.utils.ImageLoader
import com.dahe.mylibrary.utils.PopsUtils
import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers
import io.reactivex.rxjava3.schedulers.Schedulers

/**
 * @ClassName AuthRoleActivity
 * @Author 用户
 * @Date 2024/1/25 11:15
 * @Description 驾驶证认证
 */
class AuthDriverActivity : BaseActivity<ActivityAuthDriverBinding>() {

    var ossServiceUtil: OssServiceUtil = OssServiceUtil.getInstance()

    var driverInfoBean: UpDriverInfoBean = UpDriverInfoBean()

    override fun initView(savedInstanceState: Bundle?) {
        setStatusBarColor(R.color.white)
        setTitleBar("实名认证", true)

        binding.run {
            btnOk.setOnClickListener {
                subMit()
            }

            tvStart.run {
                setOnClickListener {
                    PickerUtils.getInstance()
                        .showDate(this@AuthDriverActivity, "有效起始日期") { year, month, day ->
                            this.text = "$year-$month-$day"
                        }
                }
            }
            tvEnd.run {
                setOnClickListener {
                    PickerUtils.getInstance()
                        .showDate(this@AuthDriverActivity, "有效结束日期") { year, month, day ->
                            this.text = "$year-$month-$day"
                        }
                }
            }
            tvCarType.setOnClickListener {
                PickerUtils.getInstance()
                    .showSelectCarType(this@AuthDriverActivity, "选择准驾车型") { _, item ->
                        tvCarType.text = item.toString()
                    }
            }

            ivFront.setOnClickListener {
                selFrontPic()
            }

            ivBack.setOnClickListener {
                selBackPic()
            }

        }
    }

    override fun initDate() {
    }

    private fun subMit() {
        binding.run {
            driverInfoBean.run {
                licenseNo = etId.text.toString()
                licenseType = tvCarType.text.toString()
                licenseEffectiveStart = tvStart.text.toString()
                licenseEffectiveEnd = tvEnd.text.toString()
            }

            DataManager.getInstance().setUpDriverLicense(driverInfoBean)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(BaseObserver(mContext, object : RxHttpCallBack<String>() {
                    override fun onSuccess(t: CommonResponseBean<String>) {
                        super.onSuccess(t)
                        ActivityUtils.startActivity(
                            mContext,
                            AuthQualificationActivity::class.java
                        )
                    }
                }))
        }
    }

    private fun selFrontPic() {
        OcrUtils.getInstance().ocrDriver(mContext, this@AuthDriverActivity) { picPath, result ->
            result.data.face?.data.let {
                ImageLoader.getInstance().loadRoundImage(mContext, picPath, 12, binding.ivFront)
                driverInfoBean.licensePhotoFaceUrl = picPath.picPath
                it?.run {
                    driverInfoBean.run {
                        licenseApproveOrganization =
                            issueAuthority //发证机关
                    }
                    binding.run {
                        etName.setText(it.name)
                        etId.setText(it.licenseNumber)
                        tvCarType.text = it.approvedType
                        if (validPeriod.contains("至")) {
                            val split = validPeriod.split("至")
                            tvStart.text = split[0]
                            tvEnd.text =
                                if (split.size == 2) split[1] else ""
                        }
                    }
                }
            }
        }


//        PopsUtils.getInstance().showSimSelPic(mContext) {
//            var data = it[0]
//            ossServiceUtil.asyncPutImage(data.realPath, this@AuthDriverActivity)
//            ossServiceUtil.setResultCallBack { data, oldPath ->
//                DataManager.getInstance().recognizeDrivingLicense(oldPath)
//                    .subscribeOn(Schedulers.io())
//                    .observeOn(AndroidSchedulers.mainThread())
//                    .subscribe(
//                        BaseObserver(mContext,
//                            object : RxHttpCallBack<OcrPersonBean>() {
//                                override fun onSuccess(t: CommonResponseBean<OcrPersonBean>) {
//                                    super.onSuccess(t)
//                                    t.data.data.face?.data.let {
//                                        driverInfoBean.licensePhotoFaceUrl = oldPath
//                                        it?.run {
//                                            driverInfoBean.run {
//                                                licenseApproveOrganization =
//                                                    issueAuthority //发证机关
//                                            }
//
//
//                                            binding.run {
//                                                etName.setText(it.name)
//                                                etId.setText(it.licenseNumber)
//                                                tvCarType.text = it.approvedType
//                                                if (validPeriod.contains("至")) {
//                                                    val split = validPeriod.split("至")
//                                                    tvStart.text = split[0]
//                                                    tvEnd.text =
//                                                        if (split.size == 2) split[1] else ""
//                                                }
//                                            }
//                                        }
//                                    }
//                                }
//                            })
//                    )
//
//            }
//
//            ImageLoader.getInstance().loadRoundImage(mContext, data.realPath, 12, binding.ivFront)
//        }
    }

    private fun selBackPic() {
        PopsUtils.getInstance().showSimSelPic(mContext) {
            var data = it[0]
            ossServiceUtil.asyncPutImage(data.realPath, this@AuthDriverActivity)
            ossServiceUtil.setResultCallBack { data, oldPath ->
                run {
                    DataManager.getInstance().recognizeDrivingLicense(oldPath)
                        .subscribeOn(Schedulers.io())
                        .observeOn(AndroidSchedulers.mainThread())
                        .subscribe(
                            BaseObserver(mContext,
                                object : RxHttpCallBack<OcrPersonBean>() {
                                    override fun onSuccess(t: CommonResponseBean<OcrPersonBean>) {
                                        super.onSuccess(t)
                                        t.data.data.back?.data.let {
                                            driverInfoBean.licensePhotoBackUrl = oldPath
//                                                    it?.run {
//                                                        driverInfoBean.run {
//                                                            licenseApproveOrganization =
//                                                                issueAuthority //发证机关
//                                                        }
//                                                        binding.run {
//                                                            etName.setText(it.name)
//                                                            etId.setText(it.licenseNumber)
//                                                            tvCarType.text = it.approvedType
//                                                            if (validPeriod.contains("至")) {
//                                                                val split = validPeriod.split("至")
//                                                                tvStart.text = split[0]
//                                                                tvEnd.text =
//                                                                    if (split.size == 2) split[1] else ""
//                                                            }
//                                                        }
//                                                    }
                                        }
                                    }
                                })
                        )

                }
            }


            ImageLoader.getInstance().loadRoundImage(mContext, data.realPath, 12, binding.ivBack)
        }
    }
}